@@ -464,6 +464,17 @@ baz(Baz) :- bar(Baz).
 "
                    )))
 
+(sweeprolog-deftest cap-flag-name ()
+  "Completion at point for Prolog flag names."
+  "
+foo :-
+    current_prolog_flag(double_q-!-
+"
+  (let ((res (sweeprolog-completion-at-point)))
+    (should (= (nth 0 res) 33))
+    (should (= (nth 1 res) 41))
+    (should (equal (nth 2 res) '("double_quotes")))))
+
 (sweeprolog-deftest cap-option-functor ()
   "Completion at point for predicate option functors."
   "
@@ -1368,6 +1379,23 @@ html_program_section(Section, Dict) -->
   (sweeprolog-end-of-top-term)
   (should (= (point) 466)))
 
+(sweeprolog-deftest end-of-top-term-with-dot-char-literal ()
+  "Tests detecting the fullstop in presence of `0\'.'."
+  "
+full_stop_after(Index, String, [H|T]) :-
+    string_code(Index, String, H),
+    Index2 is Index+1,
+    (   code_type(H, space)
+    ->  !, full_stop_after(Index2, String, T)
+    ;   H == 0'.
+    ->  !, layout_after(Index2, String, T)
+    ).
+full_stop_after(_, _, []).
+"
+  (goto-char (point-min))
+  (sweeprolog-end-of-top-term)
+  (should (= (point) 242)))
+
 (sweeprolog-deftest fullstop-detection ()
   "Tests detecting the fullstop in presence of confusing comments."
   "
@@ -1821,7 +1849,7 @@ head,
 "))
 
 (sweeprolog-deftest forward-sexp-with-adjacent-operators ()
-  "Tests detecting the fullstop in presence of `.=.'."
+  "Test `forward-sexp' with adjacent operators."
   "a,+b."
   (goto-char (point-min))
   (sweeprolog--forward-sexp)
@@ -1830,6 +1858,46 @@ head,
   (sweeprolog--backward-sexp)
   (should (= (point) 4)))
 
+(sweeprolog-deftest backward-sexp-over-char-literal ()
+  "Test `backward-sexp' over a charater literal."
+  "foo :- A is 0'b + 0'a + 0'r-!-."
+  (backward-sexp)
+  (should (= (point) 25))
+  (backward-sexp)
+  (should (= (point) 19))
+  (backward-sexp)
+  (should (= (point) 13))
+  (forward-sexp)
+  (should (= (point) 16))
+  (forward-sexp)
+  (should (= (point) 22))
+  (backward-sexp 2)
+  (should (= (point) 13))
+  (backward-sexp)
+  (should (= (point) 8))
+  (backward-sexp)
+  (should (= (point) 1)))
+
+(sweeprolog-deftest backward-sexp-to-string-boundary ()
+  "Test `backward-sexp' inside a string."
+  "foo :- A = \"bar, baz-!-\"."
+  (backward-sexp)
+  (should (= (point) 18))
+  (backward-sexp)
+  (should (= (point) 13))
+  (forward-sexp)
+  (should (= (point) 16))
+  (forward-sexp)
+  (should (= (point) 21)))
+
+(ert-deftest top-level-thread-id ()
+  "Test obtaining the thread id of a top-level on startup."
+  (let ((buf-name (generate-new-buffer-name "*test top-level*")))
+    (sweeprolog-top-level buf-name)
+    (should sweeprolog-top-level-thread-id)
+    (sweeprolog-top-level-delete-process buf-name)
+    (kill-buffer buf-name)))
+
 (sweeprolog-deftest usage-example-comment ()
   "Tests adding usage example comments."
   "\nfoo."
@@ -2243,8 +2311,8 @@ bbb(A, B) :-
 ")))
 
 (sweeprolog-deftest extract-region-to-predicate-ext-1 ()
-                    "Test `sweeprolog-extract-region-to-predicate'."
-                    "
+  "Test `sweeprolog-extract-region-to-predicate'."
+  "
 :- module(bbb, []).
 
 bar(A, Y) :-
@@ -2305,17 +2373,17 @@ bbb(VarName) :-
 ")))
 
 (sweeprolog-deftest extract-region-to-predicate-lambda-2 ()
-                    "Test `sweeprolog-extract-region-to-predicate'."
-                    "
+  "Test `sweeprolog-extract-region-to-predicate'."
+  "
 :- module(bbb, []).
 
 bar(A, Y) :-
     maplist({GoalVarNames}/[VarName]>>ignore(memberchk(VarName, GoalVarNames)),
             TemplateVarNames).
 "
-                    (sweeprolog-extract-region-to-predicate 48 114 "bbb")
-                    (should (string= (buffer-string)
-                                     "
+  (sweeprolog-extract-region-to-predicate 48 114 "bbb")
+  (should (string= (buffer-string)
+                   "
 :- module(bbb, []).
 
 bar(A, Y) :-
@@ -2325,4 +2393,38 @@ bar(A, Y) :-
 bbb(GoalVarNames, VarName) :-
     ignore(memberchk(VarName, GoalVarNames)).
 ")))
+
+(sweeprolog-deftest eldoc-dcg ()
+  "Test `sweep_short_documentation/2' with DCG body terms."
+  "
+:- module(eldocdcg, []).
+
+%!  foo(-Baz:string)// is det.
+%
+%   Doit.
+
+foo(Bar) --> baz(Bar).
+"
+  (should (equal (sweeprolog--query-once
+                  "sweep" "sweep_short_documentation"
+                  (list "bar --> foo(bar), foo(baz)." 12 (buffer-file-name)))
+                 (list "eldocdcg:foo//1" "foo(-Baz:string)// is det.
+    Doit.
+" (cons 4 15)))))
+
+(sweeprolog-deftest eldoc-dcg-atom ()
+  "Test `sweep_short_documentation/2' with atom non-terminals."
+  "
+:- module(eldocdcgatom, []).
+
+:- use_module(library(dcg/basics)).
+"
+  (should (equal (sweeprolog--query-once
+                  "sweep" "sweep_short_documentation"
+                  (list "bar --> blanks." 9 (buffer-file-name)))
+                 (list "dcg_basics:blanks//0" "blanks// is det.
+    Skip zero or more white-space characters.
+" nil))))
+
+
 ;;; sweeprolog-tests.el ends here
