@@ -787,7 +787,7 @@ py_initialize :-
     current_prolog_flag(executable, Program),
     current_prolog_flag(py_argv, Argv),
     py_initialize(Program, ['-I'|Argv], []),
-    py_call(sys:prefix = VEnv),
+    py_setattr(sys, prefix, VEnv),
     venv_update_path(VEnvDir).
 py_initialize :-
     current_prolog_flag(executable, Program),
@@ -809,7 +809,7 @@ venv_update_path(VEnvDir) :-
     py_call(sys:path, Path0),
     exclude(is_site_dir, Path0, Path1),
     append(Path1, [PyEnvSiteDir], Path),
-    py_call(sys:path = Path),
+    py_setattr(sys, path, Path),
     print_message(silent, janus(venv(VEnvDir, EnvSiteDir))),
     asserta(py_venv(VEnvDir, EnvSiteDir)).
 
@@ -942,15 +942,18 @@ py_add_lib_dir_(OSDir, Where) :-
     ;   must_be(oneof([first,last]), Where)
     ).
 
+:- det(repl_add_cwd/0).
 repl_add_cwd :-
     current_prolog_flag(break_level, Level),
     Level >= 0,
+    !,
     (   py_call(sys:path:count(''), N),
         N > 0
     ->  true
     ;   print_message(informational, janus(add_cwd)),
         py_add_lib_dir_('', first)
     ).
+repl_add_cwd.
 
 :- multifile
     prolog:repl_loop_hook/2.
