@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2008-2024, University of Amsterdam
+    Copyright (c)  2008-2023, University of Amsterdam
 			      VU University Amsterdam
 			      SWI-Prolog Solutions b.v.
     All rights reserved.
@@ -60,7 +60,7 @@ extern "C" {
 /* PLVERSION_TAG: a string, normally "", but for example "rc1" */
 
 #ifndef PLVERSION
-#define PLVERSION 90208
+#define PLVERSION 90300
 #endif
 #ifndef PLVERSION_TAG
 #define PLVERSION_TAG ""
@@ -483,7 +483,6 @@ PL_EXPORT(int)		PL_assert(term_t term, module_t m, int flags);
 PL_EXPORT(term_t)	PL_new_term_refs(size_t n);
 PL_EXPORT(term_t)	PL_new_term_ref(void);
 PL_EXPORT(term_t)	PL_copy_term_ref(term_t from);
-PL_EXPORT(void)		PL_free_term_ref(term_t t);
 PL_EXPORT(void)		PL_reset_term_refs(term_t r);
 
 			/* Constants */
@@ -521,7 +520,8 @@ PL_EXPORT(int)		PL_get_atom(term_t t, atom_t *a) WUNUSED;
 PL_EXPORT(int)		PL_get_bool(term_t t, int *value) WUNUSED;
 PL_EXPORT(int)		PL_get_atom_chars(term_t t, char **a) WUNUSED;
 #define PL_get_string_chars(t, s, l) PL_get_string(t,s,l)
-PL_EXPORT(int)		PL_get_string(term_t t, char **s, size_t *len) WUNUSED; /* WDEPRECATED */
+					/* PL_get_string() is deprecated */
+PL_EXPORT(int)		PL_get_string(term_t t, char **s, size_t *len) WUNUSED;
 PL_EXPORT(int)		PL_get_chars(term_t t, char **s, unsigned int flags) WUNUSED;
 PL_EXPORT(int)		PL_get_list_chars(term_t l, char **s,
 					  unsigned int flags) WUNUSED;
@@ -877,9 +877,6 @@ PL_EXPORT(int)		PL_same_compound(term_t t1, term_t t2);
 PL_EXPORT(int)		PL_warning(const char *fmt, ...) WPRINTF12;
 PL_EXPORT(int)		PL_warningX(const char *fmt, ...);
 PL_EXPORT(void)		PL_fatal_error(const char *fmt, ...) WPRINTF12;
-PL_EXPORT(void)		PL_api_error(const char *fmt, ...) WPRINTF12;
-PL_EXPORT(void)		PL_system_error(const char *fmt, ...) WPRINTF12;
-PL_EXPORT(int)		PL_print_message(atom_t severity, ...) WUNUSED;
 
 		 /*******************************
 		 *      RECORDED DATABASE	*
@@ -1293,7 +1290,6 @@ PL_EXPORT(intptr_t)	PL_query(int);	/* get information from Prolog */
 
 #define PL_THREAD_NO_DEBUG	0x01	/* Start thread in nodebug mode */
 #define PL_THREAD_NOT_DETACHED	0x02	/* Allow Prolog to join */
-#define PL_THREAD_CUR_STREAMS   0x04	/* Copy current{input,output} */
 
 typedef enum
 { PL_THREAD_CANCEL_FAILED = FALSE,	/* failed to cancel; try abort */
@@ -1350,24 +1346,22 @@ PL_EXPORT(int)		PL_destroy_engine(PL_engine_t engine);
 		 *******************************/
 typedef _PLS(table)	  *hash_table_t;
 typedef _PLS(table_enum) *hash_table_enum_t;
-typedef void *table_key_t;	/* introduced abstract types for forward compatibility */
-typedef void *table_value_t;
 
 #define PL_HT_NEW	0x0001
 #define PL_HT_UPDATE	0x0002
 
 PL_EXPORT(hash_table_t)	PL_new_hash_table(int size,
-					  void (*free_symbol)(table_key_t n, table_value_t v));
+					  void (*free_symbol)(void *n, void *v));
 PL_EXPORT(int)		PL_free_hash_table(hash_table_t table);
-PL_EXPORT(table_value_t) PL_lookup_hash_table(hash_table_t table, table_key_t key);
-PL_EXPORT(table_value_t) PL_add_hash_table(hash_table_t table,
-					   table_key_t key, table_value_t value, int flags);
-PL_EXPORT(table_value_t) PL_del_hash_table(hash_table_t table, table_key_t key);
+PL_EXPORT(void*)	PL_lookup_hash_table(hash_table_t table, void *key);
+PL_EXPORT(void*)	PL_add_hash_table(hash_table_t table,
+					  void *key, void *value, int flags);
+PL_EXPORT(void*)	PL_del_hash_table(hash_table_t table, void *key);
 PL_EXPORT(int)		PL_clear_hash_table(hash_table_t table);
 PL_EXPORT(hash_table_enum_t) PL_new_hash_table_enum(hash_table_t table);
 PL_EXPORT(void)		PL_free_hash_table_enum(hash_table_enum_t e);
 PL_EXPORT(int)		PL_advance_hash_table_enum(hash_table_enum_t e,
-						   table_key_t *key, table_value_t *value);
+						   void **key, void **value);
 
 
 		 /*******************************
